@@ -2,8 +2,11 @@
 
 Functions:
     fix_code: Fix python source code to correct missed or unused import statements.
-
     fix_files: Fix the python source code of a list of files.
 """
 
-from .services import fix_code, fix_files  # noqa W0611
+from typing import List
+
+from .services import fix_code, fix_files
+
+__all__: List[str] = ["fix_code", "fix_files"]
